@@ -305,7 +305,11 @@ def self_update(yes: bool = typer.Option(False, "--yes", help="Skip confirmation
     ])
     typer.secho("✅ Update complete!", fg=typer.colors.GREEN)
 
-if __name__ == "__main__":
+@app.callback()
+def main():
+    print("💥 CALLBACK RAN 💥")
     check_for_updates()
+
+if __name__ == "__main__":
     app()
 
